@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: hxcleng.cpp,v 1.44.2.5 2004/07/09 02:05:57 hubbe Exp $
+ * Source last modified: $Id: hxcleng.cpp,v 1.44.2.6 2005/01/06 18:07:29 rishimathew Exp $
  * 
  * Portions Copyright (c) 1995-2004 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -2482,6 +2482,19 @@ void HXClientEngine::Close()
     HX_RELEASE(m_pOrigPreferences);
     }
 #endif /* HELIX_FEATURE_PREFERENCES */
+
+#ifdef _UNIX
+    if (m_select_callbacks)
+    {
+        while (m_select_callbacks->GetCount() > 0)
+        {
+            CHXSelectCallback* scb = (CHXSelectCallback*) m_select_callbacks->RemoveHead();
+            HX_DELETE(scb);
+        }
+    }
+    HX_DELETE(m_select_callbacks);
+
+#endif /* _UNIX */
 }
 
 /*
