@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: hxtac.cpp,v 1.9.20.1 2004/07/09 02:05:58 hubbe Exp $
+ * Source last modified: $Id: hxtac.cpp,v 1.9.20.2 2004/09/08 21:09:01 sehancher Exp $
  * 
  * Portions Copyright (c) 1995-2004 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -447,8 +447,12 @@ BOOL HXMasterTAC::CheckTrackAndSourceOnTrackStarted(INT32 nGroup,
  */
 BOOL HXMasterTAC::CheckGroupForTACInfo(INT32 nGroup)
 {
-    BOOL bFoundTAC = FALSE;
-
+    BOOL bFoundTAC = CheckPresentationForTACInfo();
+    if (bFoundTAC)
+    {
+	return bFoundTAC;
+    }
+	
     // first get the group object's properties using the IHXGroup
     IHXGroup* pGroup = NULL;
     if (m_pGroupManager && 
@@ -508,6 +512,34 @@ BOOL HXMasterTAC::CheckGroupForTACInfo(INT32 nGroup)
     return bFoundTAC;
 }
 
+/************************************************************************
+ *      Method:
+ *          HXMasterTAC::CheckPresentationForTACInfo
+ *      Purpose:
+ *           Private function used to examine presentation props for TAC info
+ *
+ */
+BOOL HXMasterTAC::CheckPresentationForTACInfo()
+{
+    BOOL bFoundTAC = FALSE;
+
+    IHXValues* pPresProps = m_pGroupManager ? m_pGroupManager->GetPresentationProperties() : NULL;
+    if (pPresProps)
+    {
+	// now search the group props for TAC info
+	RetrieveTACProperties(pPresProps);
+	if (m_pTACProps && IsTACComplete(m_pTACProps))
+	{
+	    SetTAC(m_pTACProps, TAC_Presentation);
+
+	    bFoundTAC = TRUE;
+	}
+	HX_RELEASE(pPresProps);
+    }
+
+    return bFoundTAC;
+}
+
 /************************************************************************
  *      Method:
  *          HXMasterTAC::CheckTrackForTACInfo
@@ -517,8 +549,12 @@ BOOL HXMasterTAC::CheckGroupForTACInfo(INT32 nGroup)
  */
 BOOL HXMasterTAC::CheckTrackForTACInfo(INT32 nGroup, INT32 nTrack)
 {
-    BOOL bFoundTAC = FALSE;
-
+    BOOL bFoundTAC = CheckPresentationForTACInfo();
+    if (bFoundTAC)
+    {
+	return bFoundTAC;
+    }
+	
     // first get the group object's properties using the IHXGroup
     IHXGroup* pGroup = NULL;
     if (m_pGroupManager && 
