@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: atomicbase.h,v 1.23.2.6 2004/07/09 01:45:08 hubbe Exp $
+ * Source last modified: $Id: atomicbase.h,v 1.23.2.8 2004/12/22 20:00:41 nhart Exp $
  * 
  * Portions Copyright (c) 1995-2004 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -56,7 +56,7 @@
 
 
 /****************************************************************************
- *  $Id: atomicbase.h,v 1.23.2.6 2004/07/09 01:45:08 hubbe Exp $
+ *  $Id: atomicbase.h,v 1.23.2.8 2004/12/22 20:00:41 nhart Exp $
  *
  *  atomicbase.h - Defines several atomic operations
  * 
@@ -532,7 +532,7 @@ static __inline INT32 HXAtomicSubRetINT32(INT32* p, INT32 n) { return HXAtomicSu
 
 
 /***********************************************************************
- * Intel x86 (gcc) / Unix  -- i486 and higher
+ * Intel x86 (gcc) / Unix  -- i486 and higher - 32-bit
  *
  * Implementation Notes:
  *   'xadd' is only available in the 486 series and later, not the 386.
@@ -671,6 +671,136 @@ static __inline__ INT32 HXAtomicSubRetINT32(INT32* p, INT32 n) { return HXAtomic
 
 
 
+/***********************************************************************
+ * Intel x86/amd64/x86_64 (gcc) / Unix  -- 64-bit
+ *
+ * Implementation Notes:
+ *
+ */
+#elif defined(__GNUC__) && (defined (__amd64__) || defined (__x86_64__))
+
+/* Increment by 1 */
+static __inline__ void
+HXAtomicIncUINT32(UINT32* pNum)
+{
+    __asm__ __volatile__(
+        "lock incl (%%rax);"             // atomically add 1 to *pNum
+        : /* no output */
+        : "a" (pNum)
+        : "cc", "memory"
+        );
+}
+
+/* Decrement by 1 */
+static __inline__ void
+HXAtomicDecUINT32(UINT32* pNum)
+{
+    __asm__ __volatile__(
+        "lock decl (%%rax);"             // atomically add -1 to *pNum
+        : /* no output */
+        : "a" (pNum)
+        : "cc", "memory"
+        );
+}
+
+/* Increment by 1 and return new value */
+static __inline__ UINT32
+HXAtomicIncRetUINT32(UINT32* pNum)
+{
+    volatile UINT32 ulRet;
+    __asm__ __volatile__(
+        "lock xaddl %%ebx, (%%rax);"     // atomically add 1 to *pNum
+        "     incl  %%ebx;"              // old value in %%ebx, increment it
+        : "=b" (ulRet)
+        : "a" (pNum), "b" (0x1)
+        : "cc", "memory"
+        );
+    return ulRet;
+}
+
+/* Decrement by 1 and return new value */
+static __inline__ UINT32
+HXAtomicDecRetUINT32(UINT32* pNum)
+{   
+    volatile UINT32 ulRet;
+    __asm__ __volatile__(
+        "lock xaddl %%ebx, (%%rax);"     // atomically add -1 to *pNum
+        "     decl  %%ebx;"              // old value in %%ebx, decrement it
+        : "=b" (ulRet)
+        : "a" (pNum), "b" (-1)
+        : "cc", "memory"
+        );
+    return ulRet;
+}
+
+/* Add n */
+static __inline__ void
+HXAtomicAddUINT32(UINT32* pNum, UINT32 ulNum)
+{
+    __asm__ __volatile__(
+        "lock addl %%ebx, (%%rax);"      // atomically add ulNum to *pNum
+        : /* no output */
+        : "a" (pNum), "b" (ulNum)
+        : "cc", "memory"
+        );
+}
+
+/* Subtract n */
+static __inline__ void
+HXAtomicSubUINT32(UINT32* pNum, UINT32 ulNum)
+{
+    __asm__ __volatile__(
+        "lock subl %%ebx, (%%rax);"      // atomically add ulNum to *pNum
+        : /* no output */
+        : "a" (pNum), "b" (ulNum)
+        : "cc", "memory"
+        );
+}
+
+/* Add n and return new value */
+static __inline__ UINT32
+HXAtomicAddRetUINT32(UINT32* pNum, UINT32 ulNum)
+{
+    volatile UINT32 ulRet;
+    __asm__ __volatile__(
+        "     movl  %%ebx, %%ecx;"       // copy ulNum into %0
+        "lock xaddl %%ecx, (%%rax);"     // atomically add ulNum to *pNum
+        "     addl  %%ebx, %%ecx;"       // old value in %%ecx, add ulNum
+        : "=c" (ulRet)
+        : "a" (pNum), "b" (ulNum), "c" (0)
+        : "cc", "memory"
+        );
+    return ulRet;
+}
+
+/* Subtract n and return new value */
+static __inline__ UINT32
+HXAtomicSubRetUINT32(UINT32* pNum, UINT32 ulNum) 
+{   
+    volatile UINT32 ulRet;
+    __asm__ __volatile__(
+        "     subl  %%ebx, %%ecx;"       // negate ulNum, saving in %0
+        "lock xaddl %%ecx, (%%rax);"     // atomically add -(ulNum) to *pNum
+        "     subl  %%ebx, %%ecx;"       // old value in %%ecx, subtract ulNum
+        : "=c" (ulRet)
+        : "a" (pNum), "b" (ulNum), "c" (0)
+        : "cc", "memory"
+        );
+    return ulRet;
+}
+
+
+static __inline__ void HXAtomicIncINT32(INT32* p)              { HXAtomicIncUINT32((UINT32*)p); }
+static __inline__ void HXAtomicDecINT32(INT32* p)              { HXAtomicDecUINT32((UINT32*)p); }
+static __inline__ void HXAtomicAddINT32(INT32* p, INT32 n)     { HXAtomicAddUINT32((UINT32*)p, (UINT32)n); }
+static __inline__ void HXAtomicSubINT32(INT32* p, INT32 n)     { HXAtomicSubUINT32((UINT32*)p, (UINT32)n); }
+static __inline__ INT32 HXAtomicIncRetINT32(INT32* p)          { return HXAtomicIncRetUINT32((UINT32*)p); }
+static __inline__ INT32 HXAtomicDecRetINT32(INT32* p)          { return HXAtomicDecRetUINT32((UINT32*)p); }
+static __inline__ INT32 HXAtomicAddRetINT32(INT32* p, INT32 n) { return HXAtomicAddRetUINT32((UINT32*)p, (UINT32)n); }
+static __inline__ INT32 HXAtomicSubRetINT32(INT32* p, INT32 n) { return HXAtomicSubRetUINT32((UINT32*)p, (UINT32)n); }
+
+
+
 /***********************************************************************
  * HP-UX / IA64 (Native compiler)
  *
@@ -1047,6 +1177,7 @@ HXAtomicDecRetUINT32(UINT32* pNum)
  */
 #elif defined(_HPUX) || defined(_OPENBSD)
 
+#if defined(__cplusplus)
 #include "microsleep.h"
 #include "hxcom.h"
 #include "hxmutexlock.h"
@@ -1094,6 +1225,7 @@ extern HXAtomic g_AtomicOps; //in common/util/atomicops.cpp
 #define HXAtomicSubRetUINT32(p,n) g_AtomicOps._SubRetUINT32((p),(n))
 #define HXAtomicAddUINT32(p,n)    g_AtomicOps._AddRetUINT32((p),(n))
 #define HXAtomicSubUINT32(p,n)    g_AtomicOps._SubRetUINT32((p),(n))
+#endif
 
 
 
