@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: hxausvc.h,v 1.4.2.3 2004/07/09 01:45:08 hubbe Exp $
+ * Source last modified: $Id: hxausvc.h,v 1.4.2.5 2004/10/25 21:13:19 gwright Exp $
  * 
  * Portions Copyright (c) 1995-2004 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -1608,4 +1608,44 @@ DECLARE_INTERFACE_(IHXAudioMultiChannel, IUnknown)
 };
 // $EndPrivate.
 
+
+#if defined(HELIX_FEATURE_TIMELINE_WATCHER)
+
+// {211A3CAE-F1DA-4678-84D5-0F12E7B1D8C6}
+DEFINE_GUID(IID_IHXTimelineWatcher, 
+            0x211a3cae, 0xf1da, 0x4678, 0x84, 0xd5, 0xf, 0x12, 0xe7, 0xb1, 0xd8, 0xc6);
+#undef INTERFACE
+#define INTERFACE IHXTimelineWatcher
+DECLARE_INTERFACE_(IHXTimelineWatcher, IUnknown)
+{
+    STDMETHOD(QueryInterface) (THIS_ REFIID riid, void** ppvObj) PURE;
+    STDMETHOD_(ULONG32,AddRef) (THIS) PURE;
+    STDMETHOD_(ULONG32,Release) (THIS) PURE;
+
+    STDMETHOD(OnPause) (THIS) PURE;
+    STDMETHOD(OnResume) (THIS) PURE;
+    STDMETHOD(OnClose) (THIS) PURE;
+    STDMETHOD(OnTimeSync) (THIS_ UINT32 currentTime ) PURE;
+};
+
+// TimelineManager
+// {9ED91BC3-9E92-46bb-A094-6C8B9416CFB6}
+DEFINE_GUID(IID_IHXTimelineManager, 
+            0x9ed91bc3, 0x9e92, 0x46bb, 0xa0, 0x94, 0x6c, 0x8b, 0x94, 0x16, 0xcf, 0xb6);
+#undef INTERFACE
+#define INTERFACE IHXTimelineManager 
+DECLARE_INTERFACE_(IHXTimelineManager, IUnknown)
+{
+    STDMETHOD(QueryInterface) (THIS_ REFIID riid, void** ppvObj) PURE;
+    STDMETHOD_(ULONG32,AddRef) (THIS) PURE;
+    STDMETHOD_(ULONG32,Release) (THIS) PURE;
+
+    STDMETHOD(AddTimelineWatcher) (THIS_ IHXTimelineWatcher* ) PURE;
+    STDMETHOD(RemoveTimelineWatcher) (THIS_ IHXTimelineWatcher* ) PURE;
+};
+#endif /* #if defined(HELIX_FEATURE_TIMELINE_WATCHER) */
+
+
+
+
 #endif  /* _HXAUSVC_H_ */
