@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: UnixThreads.cpp,v 1.8.2.3 2004/07/09 01:43:30 hubbe Exp $
+ * Source last modified: $Id: UnixThreads.cpp,v 1.8.2.5 2004/12/24 00:30:13 rishimathew Exp $
  * 
  * Portions Copyright (c) 1995-2004 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -774,7 +774,7 @@ HX_RESULT HXUnixCondition::MakeCondition( HXUnixCondition*& pCond,
 {
     HX_ASSERT( pMutex==NULL);
     
-#if defined( _LINUX ) && defined(_UNIX_THREADS_SUPPORTED) || defined(_MAC_UNIX)
+#if defined( _LINUX ) && defined(_UNIX_THREADS_SUPPORTED) || defined(_MAC_UNIX) || defined( _HPUX )
     pCond = (HXUnixCondition*) new HXPthreadCondition(pMutex);
 #elif defined(_SOLARIS)
     pCond = (HXUnixCondition*) new HXSolarisCondition(pMutex);
@@ -870,6 +870,7 @@ HXUnixAsyncTimer::~HXUnixAsyncTimer()
     //Wait for it to stop.
     m_pMessagePump->JoinThread();
     HX_DELETE( m_pMessagePump );
+	HX_DELETE(m_pMsg);
 }
 
 ULONG32 HXUnixAsyncTimer::GetID()
