@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: nsHXPlayer.cpp,v 1.5.2.5 2004/07/09 01:48:45 hubbe Exp $
+ * Source last modified: $Id: nsHXPlayer.cpp,v 1.5.2.6 2004/11/23 00:24:25 rggammon Exp $
  * 
  * * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -65,9 +65,11 @@ nsHXPlayer::nsHXPlayer(CHXPlayerBackend *pBackend)
       m_iPlayerID(-1),
       m_instance(NULL),
       m_szName(NULL),
-      m_bIsFirstNewStream(TRUE),
-      m_bReceivedXEmbedQuery(FALSE),
-      m_bIsInitialized(FALSE),
+      m_bIsFirstNewStream(PR_TRUE),
+      m_bReceivedXEmbedQuery(PR_FALSE),
+      m_bIsInitialized(PR_FALSE),
+      m_bReceivedScriptableInstanceQuery(PR_FALSE),
+      m_bSentBrowserInfo(PR_FALSE),
       m_pBackend(pBackend)
 {    
 }
@@ -399,7 +401,42 @@ nsresult nsHXPlayer::SetPlayerStringProp(const char *szPropName, const char *szV
     return m_pBackend->ReadGenericResponse(retval);
 }
 
+nsresult nsHXPlayer::SendBrowserInfo(void)
+{
+    /* Send the browser's User Agent and JavaScript support level */
+    int nLen = 0;
+    char *pMsg;
+    nsresult result;
+    PRBool retval;
+    const char* szUserAgent = NPN_UserAgent(m_instance);
+    PRBool bHasCallbacks = m_pBackend->AreCallbacksSupported();
+    char* szQuotedUserAgent = GetQuotedString(szUserAgent);
+    
+    nLen = asprintf(&pMsg, "Browser %d %s %d %d\n",
+                    m_iPlayerID,
+                    szQuotedUserAgent,
+                    bHasCallbacks,
+                    m_bReceivedXEmbedQuery);
 
+    free(szQuotedUserAgent);
+    
+    result = m_pBackend->SendMessage(pMsg, nLen);
+    free(pMsg);
+    if(NS_FAILED(result))
+    {
+        return NPERR_GENERIC_ERROR;
+    }
+
+    result = m_pBackend->ReadGenericResponse(&retval);
+    if(NS_FAILED(result))
+    {
+        return NPERR_GENERIC_ERROR;
+    }
+
+    return NPERR_NO_ERROR;    
+}    
+
+    
 // integration APIs
 nsresult nsHXPlayer::Init(nsPluginCreateData * aCreateDataStruct)
 {
@@ -410,14 +447,14 @@ nsresult nsHXPlayer::Init(nsPluginCreateData * aCreateDataStruct)
     char* szEmbed = "Embed ";
     nsresult result;
     char *pMsg;
-    bool bSrcFound = FALSE;
+    PRBool bSrcFound = PR_FALSE;
 
     int argc = aCreateDataStruct->argc;
     char **argv = aCreateDataStruct->argv;
     char **argn = aCreateDataStruct->argn;
 
     m_instance = aCreateDataStruct->instance;
-    m_bIsInitialized = TRUE;
+    m_bIsInitialized = PR_TRUE;
     
     // See if we were passed a "src" attribute -- if we weren't,
     // we aren't going to get an inital stream
@@ -425,13 +462,13 @@ nsresult nsHXPlayer::Init(nsPluginCreateData * aCreateDataStruct)
     {
         if(strcasecmp(aCreateDataStruct->argn[i], "src") == 0)
         {
-            bSrcFound = TRUE;
+            bSrcFound = PR_TRUE;
         }
     }
     
     if(!bSrcFound)
     {
-        m_bIsFirstNewStream = FALSE;
+        m_bIsFirstNewStream = PR_FALSE;
     }
     
     for(i = 0; i < argc; i++)
@@ -483,7 +520,6 @@ nsresult nsHXPlayer::Init(nsPluginCreateData * aCreateDataStruct)
 
     free(pMsg);
 
-
     m_pBackend->AddHXPlayer(this);
 
     return result;
@@ -492,7 +528,7 @@ nsresult nsHXPlayer::Init(nsPluginCreateData * aCreateDataStruct)
 nsresult nsHXPlayer::Destroy(void)
 {
     SetWindow(NULL);
-    m_bIsInitialized = FALSE;
+    m_bIsInitialized = PR_FALSE;
     m_pBackend->RemoveHXPlayer(this);
     
     return NS_OK;
@@ -505,6 +541,13 @@ NPError nsHXPlayer::SetWindow(NPWindow *aWindow)
     PRBool retval;
     int nLen;
     nsresult result;
+
+    if(!m_bSentBrowserInfo)
+    {
+        /* At this point, XEmbed and Scriptability info should be set */
+        SendBrowserInfo();
+        m_bSentBrowserInfo = TRUE;
+    }
     
     if(aWindow)
     {
@@ -609,7 +652,7 @@ NPError nsHXPlayer::NewStream(NPMIMEType type, NPStream* stream, NPBool /* seeka
         // playback. This makes us consistant with the behavior of the Windows
         // plugin, which doesn't start buffering until playback is requested.
 
-        m_bIsFirstNewStream = FALSE;
+        m_bIsFirstNewStream = PR_FALSE;
         
         return NPERR_NO_DATA; // Kevin Foreman wrote this line of code
     }
@@ -687,6 +730,8 @@ NPError	nsHXPlayer::GetValue(NPPVariable aVariable, void *aValue)
     {
         case NPPVpluginScriptableInstance:
             // add reference for the caller requesting the object
+            m_bReceivedScriptableInstanceQuery = PR_TRUE;
+            
             NS_ADDREF(this);
             QueryInterface(NS_GET_IID(nsISupports), (void**)aValue);
             break;
@@ -706,7 +751,7 @@ NPError	nsHXPlayer::GetValue(NPPVariable aVariable, void *aValue)
 
         case NPPVpluginNeedsXEmbed:
             *((PRBool *)aValue) = PR_TRUE;
-            m_bReceivedXEmbedQuery = true;
+            m_bReceivedXEmbedQuery = PR_TRUE;
             break;
 
         default:
