@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * Source last modified: $Id: nsHXPlayer.h,v 1.3.8.5 2004/07/09 01:48:45 hubbe Exp $
+ * Source last modified: $Id: nsHXPlayer.h,v 1.3.8.6 2004/11/23 00:24:25 rggammon Exp $
  * 
  * * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved.
  * 
@@ -96,7 +96,6 @@ public:
     NPBool isInitialized() { return m_bIsInitialized; };
 
 private:
-    // ReadGenericResponse reads a boolean using ReadMessage
     char *GetQuotedString(const char *szString);
     nsresult GetGenericResponse(PRBool* result);
     nsresult GetPlayerUINT32Prop(const char *szPropName, PRInt32 *uiValue);
@@ -107,6 +106,8 @@ private:
 
     nsresult DoCommand(const char *szCommand, PRBool *_retval);
     nsresult ReadGenericResponse(PRBool* retval);
+
+    nsresult SendBrowserInfo(void);
         
     // private data
     int m_iPlayerID;
@@ -116,6 +117,8 @@ private:
     NPBool m_bIsFirstNewStream;
     NPBool m_bReceivedXEmbedQuery;
     NPBool m_bIsInitialized;
+    NPBool m_bReceivedScriptableInstanceQuery;
+    NPBool m_bSentBrowserInfo;
     
     // Backend shared between all nsHXPlayer's
     CHXPlayerBackend *m_pBackend;
